==> kubernetes-model-1.0.34-sources.jar: io/fabric8/openshift/api/model/ImageStreamSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;

public class ImageStreamSpecFluentImpl<T extends ImageStreamSpecFluent<T>> extends BaseFluent<T> implements ImageStreamSpecFluent<T>{

     String dockerImageRepository;     List<VisitableBuilder<NamedTagReference, ?>> tags = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();
public ImageStreamSpecFluentImpl(){
    
}
public ImageStreamSpecFluentImpl( ImageStreamSpec instance ){
    this.withDockerImageRepository(instance.getDockerImageRepository()); this.withTags(instance.getTags()); 
}

    public String getDockerImageRepository(){
    return this.dockerImageRepository;
    }
    public T withDockerImageRepository( String dockerImageRepository){
    this.dockerImageRepository=dockerImageRepository; return (T) this;
    }
    public T addToTags( NamedTagReference ...items){
    for (NamedTagReference item : items) {NamedTagReferenceBuilder builder = new NamedTagReferenceBuilder(item);_visitables.add(builder);this.tags.add(builder);} return (T)this;
    }
    public T removeFromTags( NamedTagReference ...items){
    for (NamedTagReference item : items) {NamedTagReferenceBuilder builder = new NamedTagReferenceBuilder(item);_visitables.remove(builder);this.tags.remove(builder);} return (T)this;
    }
    public List<NamedTagReference> getTags(){
    return build(tags);
    }
    public T withTags( List<NamedTagReference> tags){
    this.tags.clear();if (tags != null) {for (NamedTagReference item : tags){this.addToTags(item);}} return (T) this;
    }
    public T withTags( NamedTagReference ...tags){
    this.tags.clear(); if (tags != null) {for (NamedTagReference item :tags){ this.addToTags(item);}} return (T) this;
    }
    public TagsNested<T> addNewTag(){
    return new TagsNestedImpl<T>();
    }
    public TagsNested<T> addNewTagLike( NamedTagReference item){
    return new TagsNestedImpl<T>(item);
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ImageStreamSpecFluentImpl that = (ImageStreamSpecFluentImpl) o;
if (dockerImageRepository != null ? !dockerImageRepository.equals(that.dockerImageRepository) :that.dockerImageRepository != null) return false;
if (tags != null ? !tags.equals(that.tags) :that.tags != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class TagsNestedImpl<N> extends NamedTagReferenceFluentImpl<TagsNested<N>> implements TagsNested<N>{

        private final NamedTagReferenceBuilder builder;
    
             TagsNestedImpl ( NamedTagReference item){
        this.builder = new NamedTagReferenceBuilder(this, item);
        }
             TagsNestedImpl (){
        this.builder = new NamedTagReferenceBuilder(this);
        }
    
            public N endTag(){
            return and();
        }
            public N and(){
            return (N) ImageStreamSpecFluentImpl.this.addToTags(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.46-sources.jar: io/fabric8/openshift/api/model/ImageStreamSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;

public class ImageStreamSpecFluentImpl<T extends ImageStreamSpecFluent<T>> extends BaseFluent<T> implements ImageStreamSpecFluent<T>{

     String dockerImageRepository;     List<VisitableBuilder<TagReference, ?>> tags = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();
public ImageStreamSpecFluentImpl(){
    
}
public ImageStreamSpecFluentImpl( ImageStreamSpec instance ){
    this.withDockerImageRepository(instance.getDockerImageRepository()); this.withTags(instance.getTags()); 
}

    public String getDockerImageRepository(){
    return this.dockerImageRepository;
    }
    public T withDockerImageRepository( String dockerImageRepository){
    this.dockerImageRepository=dockerImageRepository; return (T) this;
    }
    public T addToTags( TagReference ...items){
    for (TagReference item : items) {TagReferenceBuilder builder = new TagReferenceBuilder(item);_visitables.add(builder);this.tags.add(builder);} return (T)this;
    }
    public T removeFromTags( TagReference ...items){
    for (TagReference item : items) {TagReferenceBuilder builder = new TagReferenceBuilder(item);_visitables.remove(builder);this.tags.remove(builder);} return (T)this;
    }
    public List<TagReference> getTags(){
    return build(tags);
    }
    public T withTags( List<TagReference> tags){
    this.tags.clear();if (tags != null) {for (TagReference item : tags){this.addToTags(item);}} return (T) this;
    }
    public T withTags( TagReference ...tags){
    this.tags.clear(); if (tags != null) {for (TagReference item :tags){ this.addToTags(item);}} return (T) this;
    }
    public TagsNested<T> addNewTag(){
    return new TagsNestedImpl<T>();
    }
    public TagsNested<T> addNewTagLike( TagReference item){
    return new TagsNestedImpl<T>(item);
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ImageStreamSpecFluentImpl that = (ImageStreamSpecFluentImpl) o;
if (dockerImageRepository != null ? !dockerImageRepository.equals(that.dockerImageRepository) :that.dockerImageRepository != null) return false;
if (tags != null ? !tags.equals(that.tags) :that.tags != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class TagsNestedImpl<N> extends TagReferenceFluentImpl<TagsNested<N>> implements TagsNested<N>{

        private final TagReferenceBuilder builder;
    
             TagsNestedImpl (){
        this.builder = new TagReferenceBuilder(this);
        }
             TagsNestedImpl ( TagReference item){
        this.builder = new TagReferenceBuilder(this, item);
        }
    
            public N endTag(){
            return and();
        }
            public N and(){
            return (N) ImageStreamSpecFluentImpl.this.addToTags(builder.build());
        }
    
}


}
